fino
====

[![PyPI version](https://img.shields.io/pypi/v/fino.svg)](https://pypi.org/project/fino/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/fino.svg)](https://pypi.org/project/fino/)
[![Build Status](https://travis-ci.org/hugovk/fino.svg?branch=master)](https://travis-ci.org/hugovk/fino)
[![Coverage Status](https://coveralls.io/repos/github/hugovk/fino/badge.svg?branch=master)](https://coveralls.io/github/hugovk/fino?branch=master)
[![Code Health](https://landscape.io/github/hugovk/fino/master/landscape.svg)](https://landscape.io/github/hugovk/fino/master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

Output the Finnish word for a given integer.

 * Used by [hugovk/everyfinnishno](https://github.com/hugovk/everyfinnishno) to tweet [@EveryFinnishNo](https://twitter.com/EveryFinnishNo).

Installation
------------

Install via pip:

```bash
pip install fino
```

Install latest development version:

```bash
pip install -U git+https://github.com/hugovk/fino
```

Or from requirements.txt:

```txt
-e git://github.com/hugovk/fino.git#egg=pylast
```

Usage
-----

```python
>>> import fino
>>> fino.to_finnish(123)
'satakaksikymmentäkolme'
>>> fino.to_finnish(123_456)
'satakaksikymmentäkolmetuhattaneljäsataaviisikymmentäkuusi'
>>> fino.to_finnish(123_456_789)
'satakaksikymmentäkolmemiljoonaaneljäsataaviisikymmentäkuusituhattaseitsemänsataakahdeksankymmentäyhdeksän'
>>> fino.to_finnish(123_456_789_012)
'satakaksikymmentäkolmemiljardianeljäsataaviisikymmentäkuusimiljoonaaseitsemänsataakahdeksankymmentäyhdeksäntuhattakaksitoista'
>>> fino.to_finnish(123_456_789_012_345)
'satakaksikymmentäkolmebiljoonaaneljäsataaviisikymmentäkuusimiljardiaseitsemänsataakahdeksankymmentäyhdeksänmiljoonaakaksitoistatuhattakolmesataaneljäkymmentäviisi'
>>> fino.to_finnish(123_456_789_012_345_678)
'satakaksikymmentäkolmetuhattaneljäsataaviisikymmentäkuusibiljoonaaseitsemänsataakahdeksankymmentäyhdeksänmiljardiakaksitoistamiljoonaakolmesataaneljäkymmentäviisituhattakuusisataaseitsemänkymmentäkahdeksan'
```
